@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2011 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2012 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -81,9 +81,9 @@ class ListDives(object):
 
         for fin in files:
             print('{}:'.format(fin))
-            for i, dl in enumerate(kl.list_dives(fin), 1):
-                l =  ' '.join('{:>9}'.format(s) for s in dl)
-                print('{:5}: {}'.format(i, l))
+            for i, d in enumerate(kl.list_dives(fin), 1):
+                print('{:5}: {:>9} {:>9} ({:>5}) {:>9} {:>9}'.format(i,
+                    d[0], d[1], d[2] or ' --- ', d[3], d[4]))
 
 
 
