@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2011 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2012 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,7 +39,8 @@ def ntuple(name, fields):
     return dt._replace
 
 
-Dive = ntuple('Dive', 'datetime depth duration temp profile equipment')
+Dive = ntuple('Dive', 'datetime depth duration temp avg_depth profile' \
+        ' equipment')
 Sample = ntuple('Sample', 'depth time temp setpoint setpointby' \
         ' deco_time deco_depth alarm gas')
 Gas = ntuple('Gas', 'id name o2 he')
