@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2011 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2012 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@ def pressure(depth):
 
 
 @kc.inject(DeviceDriver, id='ostc', name='OSTC Driver',
-        models=('OSTC', 'OSTC Mk.2', 'OSTC N2'))
+        models=('OSTC', 'OSTC Mk.2', 'OSTC 2N'))
 class OSTCDriver(object):
     """
     OSTC dive computer driver.
@@ -168,12 +168,6 @@ class OSTCDataParser(object):
         """
         Convert dive data into UDDF format.
         """
-        # uddf dive profile sample
-        _f = 'alarm', 'deco_time', 'deco_depth', 'deco_kind', 'depth', 'time', 'temp'
-        _q = 'uddf:alarm', \
-            'uddf:decostop/@duration', 'uddf:decostop/@decodepth', 'uddf:decostop/@kind', \
-            'uddf:depth', 'uddf:divetime', 'uddf:temperature',
-                
         ostc_data = ostc_parser.get_data(dump.data)
 
         for h, p in ostc_parser.profiles(ostc_data.profiles):
@@ -194,12 +188,17 @@ class OSTCDataParser(object):
                     seconds=header.dive_time_s + header.sampling)
             st -= duration
 
+            # firmware ver < 1.91 has no average depth information
+            avg_depth = header.avg_depth / 100.0 \
+                    if hasattr(header, 'avg_depth') else None
+
             try:
                 profile = list(self._get_profile(header, dive_data))
                 yield kd.Dive(datetime=st,
                     depth=header.max_depth / 100.0,
                     duration=duration.seconds,
                     temp=C2K(header.min_temp / 10.0),
+                    avg_depth=avg_depth,
                     profile=profile)
             except ValueError as ex:
                 log.error('invalid dive {0.year:>02d}-{0.month:>02d}-{0.day:>02d}' \
@@ -266,7 +265,7 @@ class OSTCDataParser(object):
         status = ostc_parser.get_data(data)
         model = 'OSTC'
         if status.eeprom.serial > 2047:
-            model = 'OSTC N2'
+            model = 'OSTC 2N'
         elif status.eeprom.serial > 300:
             model = 'OSTC Mk.2'
         return '{} {}.{:02}'.format(model, status.ver1, status.ver2)
