@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2011 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2012 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -107,7 +107,7 @@ def header(data):
     else:
         raise ValueError('Unknown length of profile header: {}'.format(len(data)))
 
-    log.debug('parsed dive header {0.year:>02d}/{0.month:>02d}/{0.day:>02d}' \
+    log.debug('parsed dive header {0.year:>02d}-{0.month:>02d}-{0.day:>02d}' \
         ' {0.hour:>02d}:{0.minute:>02d}' \
         ' max depth={0.max_depth}'.format(header))
     return header
