@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2011 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2012 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -168,6 +168,33 @@ class DataModelTestCase(unittest.TestCase):
             tuple((float(s.deco_depth), float(s.deco_time)) for s in samples))
 
 
+    def test_no_avg_depth(self):
+        """
+        Test OSTC1 no average depth parsing
+        """
+        dive = self.dives[0]
+        self.assertTrue(dive.avg_depth is None)
+
+
+    def test_avg_depth_191(self):
+        """
+        Test OSTC 1.91 average depth parsing
+        """
+        dc = OSTCDataParser()
+
+        dump = kd.BinaryData(datetime=datetime.now(),
+                data=od.RAW_DATA_OSTC_MK2_196)
+        dive = next(dc.dives(dump))
+        self.assertEquals(7.3, dive.avg_depth)
+
+        # do not use 1st and 2nd dives as they were generated with firmware
+        # ver < 1.91
+        dump = kd.BinaryData(datetime=datetime.now(),
+                data=od.RAW_DATA_OSTC_MK2_194)
+        dive = list(dc.dives(dump))[2]
+        self.assertEquals(26.05, dive.avg_depth)
+
+
 
 class DataParserTestCase(unittest.TestCase):
     """
@@ -198,11 +225,11 @@ class DataParserTestCase(unittest.TestCase):
 
     def test_version_ostc_n2(self):
         """
-        Test OSTC N2 model and version parsing from raw data
+        Test OSTC 2N model and version parsing from raw data
         """
         dc = OSTCDataParser()
         ver = dc.version(od.RAW_DATA_OSTC_N2_191_HW)
-        self.assertEquals('OSTC N2 1.91', ver)
+        self.assertEquals('OSTC 2N 1.91', ver)
 
 
     def test_version_191(self):
