@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2011 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2012 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -85,6 +85,7 @@ UDDF_PROFILE = b"""\
             <diveduration>20</diveduration>
             <greatestdepth>30.2</greatestdepth>
             <lowesttemperature>251.4</lowesttemperature>
+            <averagedepth>10.1</averagedepth>
         </informationafterdive>
       </dive>
       <dive id='d02'>
@@ -263,6 +264,7 @@ class FindDataTestCase(unittest.TestCase):
         self.assertEquals(20, dive.duration)
         self.assertEquals(30.2, dive.depth)
         self.assertEquals(251.4, dive.temp)
+        self.assertEquals(10.1, dive.avg_depth)
 
 
     def test_profile_data(self):
@@ -392,7 +394,7 @@ class CreateDataTestCase(unittest.TestCase):
         f.close() # check if file closing is possible
 
         preamble = b"""\
-<?xml version='1.0' encoding='utf-8'?>
+<?xml version='1.0' encoding='UTF-8'?>
 <uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">\
 """
         self.assertTrue(s.startswith(preamble), s)
