@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2011 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2012 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -88,7 +88,8 @@ XP_DEFAULT_DIVE_DATA = (
     XPath('uddf:informationbeforedive/uddf:datetime/text()'),
     XPath('uddf:informationafterdive/uddf:greatestdepth/text()'),
     XPath('uddf:informationafterdive/uddf:diveduration/text()'),
-    XPath('uddf:informationafterdive/uddf:lowesttemperature/text()'))
+    XPath('uddf:informationafterdive/uddf:lowesttemperature/text()'),
+    XPath('uddf:informationafterdive/uddf:averagedepth/text()'))
 
 # XPath queries for default dive profile sample data
 XP_DEFAULT_PROFILE_DATA =  (
@@ -332,9 +333,9 @@ def dive_data(node, fields=None, queries=None, parsers=None):
         find_data
     """
     if fields is None:
-        fields = ('datetime', 'depth', 'duration', 'temp')
+        fields = ('datetime', 'depth', 'duration', 'temp', 'avg_depth')
         queries = XP_DEFAULT_DIVE_DATA
-        parsers = (dparse, float, float, float)
+        parsers = (dparse, float, float, float, float)
 
     return find_data('Dive', node, fields, queries, parsers)
 
@@ -997,6 +998,7 @@ def create_dive(dive, equipment=None):
             xml.diveduration(FMT_I(dive.duration)),
             None if dive.temp is None else xml.lowesttemperature(FMT_F(dive.temp)),
             xml.equipmentused((xml.link(ref=v) for v in eq)),
+            None if dive.avg_depth is None else xml.averagedepth(FMT_F(dive.avg_depth)),
         ),
         id=gen_id(),
     )
